@@ -23,6 +23,8 @@ RcppExport SEXP RtoGlmSmry(SEXP mpar, SEXP tpar, SEXP Ysexp, SEXP Xsexp,
     mm.varStab = as<unsigned int>(sparam["stablizer"]);
     mm.n = as<unsigned int>(sparam["n"]);
     mm.maxiter = as<unsigned int>(sparam["maxiter"]);
+    mm.maxiter2 = as<unsigned int>(sparam["maxiter2"]);
+    mm.warning = as<unsigned int>(sparam["warning"]);
 
     List rparam(tpar);
     // pass parameters
@@ -34,6 +36,7 @@ RcppExport SEXP RtoGlmSmry(SEXP mpar, SEXP tpar, SEXP Ysexp, SEXP Xsexp,
     tm.punit = as<unsigned int>(rparam["punit"]);
     tm.nboot = as<unsigned int>(rparam["nboot"]);
     tm.showtime = as<unsigned int>(rparam["showtime"]);
+    tm.warning = as<unsigned int>(rparam["warning"]);
 
 //    // for debug
 //    Rprintf("Input param arguments:\n tol=%.4f, nboot=%d, cor_type=%d, test_type=%d, resamp=%d, showtime=%d\n",mm.tol, tm.nboot, tm.corr, tm.test, tm.resamp, tm.showtime);
@@ -117,7 +120,7 @@ RcppExport SEXP RtoGlmSmry(SEXP mpar, SEXP tpar, SEXP Ysexp, SEXP Xsexp,
     unsigned int hours = floor((double)dif/(double)3600);
     unsigned int min = floor((double)(dif-hours*3600)/(double)60);
     unsigned int sec = dif - hours*3600 - min*60;
-    if (tm.showtime==TRUE)
+    if (tm.showtime>=TRUE)
        Rprintf("Time elapsed: %d hr %d min %d sec\n", hours, min, sec);
 
     // Wrap gsl vectors with Rcpp 
