@@ -8,6 +8,7 @@
 GlmTest::GlmTest(const mv_Method *tm):tm(tm)
 {  
     eps = tm->tol;
+//    eps = 1e-6;
 
     smryStat = NULL;
     Psmry = NULL;
@@ -362,11 +363,11 @@ int GlmTest::anova(glm *fit, gsl_matrix *isXvarIn)
            GeeWald(PtrAlt[mtype], L1, &teststat.vector);
         }
         else {              
-//           BetaO = gsl_matrix_alloc(nP1, nVars);
-//           addXrow2(PtrNull[mtype]->Beta, &ref1.vector, BetaO); 
+           BetaO = gsl_matrix_alloc(nP1, nVars);
+           addXrow2(PtrNull[mtype]->Beta, &ref1.vector, BetaO); 
 //	   displaymatrix(BetaO, "BetaO");
-//           PtrAlt[mtype]->regression(fit->Yref, X1, NULL, BetaO);
-           PtrAlt[mtype]->regression(fit->Yref, X1, NULL, NULL);
+           PtrAlt[mtype]->regression(fit->Yref, X1, NULL, BetaO);
+//           PtrAlt[mtype]->regression(fit->Yref, X1, NULL, NULL);
 //	   PtrNull[mtype]->display();
 //	   PtrAlt[mtype]->display();
            GeeLR(PtrAlt[mtype], PtrNull[mtype], &teststat.vector); 
@@ -417,9 +418,9 @@ int GlmTest::anova(glm *fit, gsl_matrix *isXvarIn)
             else {
                 bNull[mtype]->regression(bY,X0,bO,NULL); 
 //                bNull[mtype]->EstIRLS(bY,X0,bO,NULL,PtrNull[mtype]->phi); 
-//                addXrow2(bNull[mtype]->Beta, &ref1.vector, BetaO); 
-//                bAlt[mtype]->regression(bY,X1,bO,BetaO); 
-                bAlt[mtype]->regression(bY,X1,bO,NULL); 
+                addXrow2(bNull[mtype]->Beta, &ref1.vector, BetaO); 
+                bAlt[mtype]->regression(bY,X1,bO,BetaO); 
+//                bAlt[mtype]->regression(bY,X1,bO,NULL); 
 //                bAlt[mtype]->EstIRLS(bY,X1,bO,BetaO,PtrAlt[mtype]->phi); 
                 GeeLR(bAlt[mtype], bNull[mtype], bStat);    
             }
@@ -483,12 +484,11 @@ int GlmTest::GeeLR(glm *PtrAlt, glm *PtrNull, gsl_vector *teststat)
     double val, result=0;
     for ( unsigned int j=0; j<nVars; j++ ) { // univariates
         val = PtrAlt->ll[j] - PtrNull->ll[j];
-        if ( val<0 ) {
-//           printf("Warning: Alt ll=%.4f < Null ll=%.4f\n", PtrAlt->ll[j], PtrNull->ll[j]);
+        if ( val<-0.1 ) {
            val=0;
-//           exit(-1);
+           if (tm->warning==TRUE) 
+              printf("Warning: Alt ll=%.4f < Null ll=%.4f\n", PtrAlt->ll[j], PtrNull->ll[j]);
         } 
-//        printf("%.2f ", val);
         gsl_vector_set(teststat, j+1, val);
         result = result+val;	    
     }
@@ -511,7 +511,7 @@ int GlmTest::GeeScore(gsl_matrix *X1, glm *PtrNull, gsl_vector *teststat)
     gsl_matrix_set_zero (kRlNull);
     gsl_matrix *XwX = gsl_matrix_alloc(nP, nP);
     gsl_vector *tmp=gsl_vector_alloc(nVars*nP);
-    gsl_vector_view wj, uj, rj, tmp2, dj;
+    gsl_vector_view wj, uj, rj, tmp2; //, dj;
     gsl_matrix_view Rl;
 
     GrpMat *Z = (GrpMat*)malloc(nVars*sizeof(GrpMat));
@@ -528,17 +528,15 @@ int GlmTest::GeeScore(gsl_matrix *X1, glm *PtrNull, gsl_vector *teststat)
         gsl_blas_dgemv(CblasTrans, 1, Z[j].matrix, &rj.vector, 0, &uj.vector);
 
         if ( (tm->punit!=NONE) || (tm->corr==IDENTITY) ) {
-           gsl_matrix_set_zero(XwX);
+           gsl_matrix_set_identity(XwX);
            gsl_blas_dsyrk(CblasLower, CblasTrans, 1, Z[j].matrix, 0, XwX);
-           // univariate test = U^T*(XwX)^-1*U
-           if (calcDet(XwX)<eps) { // XwX + eps*
-              gsl_matrix_set_identity(XwX);
-              gsl_blas_dsyrk(CblasLower, CblasTrans, 1, Z[j].matrix, eps, XwX);
-           }
            status=gsl_linalg_cholesky_decomp(XwX); 
-           if (status) {
-              printf("Singular info mat in GeeScore, gsl_errno=%d\n", status);           
-//              exit(-1);
+           if (status==GSL_EDOM) {
+              if (tm->warning==TRUE)
+                  printf("Warning: singular matrix in score test. An eps*I is added to the singular matrix.\n");
+              gsl_matrix_set_identity(XwX);
+              gsl_blas_dsyrk(CblasLower,CblasTrans,1,Z[j].matrix,eps,XwX);
+              gsl_linalg_cholesky_decomp(XwX); 
            }
            tmp2=gsl_vector_subvector(tmp, 0, nP);
            gsl_linalg_cholesky_solve(XwX, &uj.vector, &tmp2.vector);
@@ -559,14 +557,14 @@ int GlmTest::GeeScore(gsl_matrix *X1, glm *PtrNull, gsl_vector *teststat)
     // multivariate test stat   
     if ( tm->corr==IDENTITY ) gsl_vector_set(teststat, 0, sum);
     else {    
-        if (calcDet(kRlNull)<eps) {
+    /*    if (calcDet(kRlNull)<eps) {
            dj=gsl_matrix_diagonal (kRlNull);
            gsl_vector_add_constant (&dj.vector, eps);
-        }
+        } */
         status=gsl_linalg_cholesky_decomp (kRlNull);
-        if (status) {
-           printf("Singular kRlNull in GeeWald, gsl_errno=%d\n", status);
-//           exit(-1);
+        if (status==GSL_EDOM) {
+           if (tm->warning==TRUE) 
+              printf("Warning:singular kRlNull in multivariate score test.\n");
         }
         gsl_linalg_cholesky_solve (kRlNull, U, tmp);
         gsl_blas_ddot (U, tmp, &result);
@@ -605,7 +603,7 @@ int GlmTest::GeeWald(glm *Alt, gsl_matrix *LL, gsl_vector *teststat)
     gsl_matrix *IinvN = gsl_matrix_alloc(nDF, nDF);
     gsl_matrix *IinvRl = gsl_matrix_alloc(nVars*nDF, nVars*nDF);
     gsl_vector *tmp = gsl_vector_alloc(nVars*nDF);
-    gsl_vector_view tmp2, wj, LBj, bj, dj; 
+    gsl_vector_view tmp2, wj, LBj, bj; //, dj; 
     gsl_matrix_view Rl;
 
     gsl_matrix_set_zero(IinvRl);
@@ -619,24 +617,23 @@ int GlmTest::GeeWald(glm *Alt, gsl_matrix *LL, gsl_vector *teststat)
        gsl_matrix_mul_elements (w1jX1, Alt->Xref);
 
        // LBeta = L*Beta       
-       LBj=gsl_vector_subvector (LBeta, j*nDF, nDF);
-       bj=gsl_matrix_column (Alt->Beta, j);
+       LBj=gsl_vector_subvector(LBeta, j*nDF, nDF);
+       bj=gsl_matrix_column(Alt->Beta, j);
        gsl_blas_dgemv(CblasNoTrans,1,LL,&bj.vector,0,&LBj.vector);
 
        // Z = (X^T W X)^-1 * X^T W^1/2. 
-       gsl_matrix_set_zero (XwX);
-       gsl_blas_dsyrk (CblasLower, CblasTrans, 1.0, w1jX1, 0.0, XwX);
-       if (calcDet(XwX)<eps) {
-          gsl_matrix_set_identity(XwX);
-          gsl_blas_dsyrk (CblasLower, CblasTrans, 1.0, w1jX1, eps, XwX);
-       }
+       gsl_matrix_set_identity(XwX);
+       gsl_blas_dsyrk (CblasLower,CblasTrans,1.0,w1jX1,0.0,XwX);
        status=gsl_linalg_cholesky_decomp (XwX);
-       if (status) {
-          printf("Singular info mat in wald test, gsl_errno=%d\n", status);
-//          exit(-1);
+       if (status==GSL_EDOM) {
+          if (tm->warning==TRUE) 
+             printf("Warning:singular matrix in wald test. An eps*I is added to the singular matrix.\n");
+          gsl_matrix_set_identity(XwX);
+          gsl_blas_dsyrk(CblasLower,CblasTrans,1.0,w1jX1,eps,XwX);
+          gsl_linalg_cholesky_decomp(XwX);
        }
-       gsl_linalg_cholesky_invert (XwX);
-       gsl_blas_dgemm (CblasNoTrans, CblasTrans, 1.0, XwX, w1jX1, 0.0, Z[j].matrix);
+       gsl_linalg_cholesky_invert(XwX);
+       gsl_blas_dgemm(CblasNoTrans,CblasTrans,1.0,XwX,w1jX1,0.0, Z[j].matrix);
 
        gsl_matrix_memcpy(Rl2, LL);
        gsl_blas_dtrmm (CblasRight,CblasLower,CblasNoTrans,CblasNonUnit,1.0,XwX,Rl2); // L*(X'WX)^-1
@@ -644,14 +641,14 @@ int GlmTest::GeeWald(glm *Alt, gsl_matrix *LL, gsl_vector *teststat)
 
        if ( (tm->punit!=NONE) || (tm->corr==IDENTITY) ) {
           // Unit test: statj=LBeta^T *(IinvN)^-1*LBeta
-          if (calcDet(IinvN)<eps) {             
+        /*  if (calcDet(IinvN)<eps) {             
              dj=gsl_matrix_diagonal (IinvN);
              gsl_vector_add_constant (&dj.vector, eps); 
-          }
+          } */
           status=gsl_linalg_cholesky_decomp (IinvN);
-          if (status) {
-             printf("Singular IinvN in univariate Wald test, calcDet(IinvN)=%.4f\n", calcDet(IinvN));
-//             exit(-1);
+          if (status==GSL_EDOM) {
+             if (tm->warning==TRUE) 
+             printf("Warning:singular IinvN in wald test.\n");
           }
           tmp2=gsl_vector_subvector(tmp, 0, nDF);
           gsl_linalg_cholesky_solve (IinvN, &LBj.vector, &tmp2.vector);
@@ -679,14 +676,14 @@ int GlmTest::GeeWald(glm *Alt, gsl_matrix *LL, gsl_vector *teststat)
         gsl_vector_set(teststat, 0, sqrt(sum));
     else {
         // Multi test: stat = LBeta^T * inv(IinvRl) * LBeta
-        if (calcDet(IinvRl)<eps) {
+       /* if (calcDet(IinvRl)<eps) {
            dj=gsl_matrix_diagonal (IinvRl);
            gsl_vector_add_constant (&dj.vector, eps);
-        }
+        } */
         status=gsl_linalg_cholesky_decomp (IinvRl);
-        if (status) {
-           printf("Singular IinvRl in multivariate Wald test, gsl_errno=%d\n", status);
-//           exit(-1);
+        if (status==GSL_EDOM) {
+           if (tm->warning==TRUE) 
+           printf("Warning:singular matrix in multivariate wald test.\n");
         }
         gsl_linalg_cholesky_solve (IinvRl, LBeta, tmp);
         gsl_blas_ddot (LBeta, tmp, &result);
@@ -710,15 +707,17 @@ int GlmTest::GeeWald(glm *Alt, gsl_matrix *LL, gsl_vector *teststat)
 
 int GlmTest::resampSmryCase(glm *model, gsl_matrix *bT, GrpMat *GrpXs, gsl_matrix *bO, unsigned int i )
 {   
-    unsigned int j, k, id, isSingular;
+    gsl_set_error_handler_off();
+    int status, isValid=TRUE;
+
+    unsigned int j, k, id;
     gsl_vector_view yj, oj, xj;
     gsl_matrix *tXX = NULL;
     unsigned int nRows=tm->nRows, nParam=tm->nParam;
     
     if (bootID == NULL) {
        tXX = gsl_matrix_alloc(nParam, nParam);
-       isSingular=TRUE;       
-       while (isSingular==TRUE) { // if all isSingular==TRUE
+       while (isValid==TRUE) { // if all isSingular==TRUE
            if (tm->reprand!=TRUE) GetRNGstate();
            for (j=0; j<nRows; j++) {
                // resample Y, X, offsets accordingly
@@ -733,9 +732,11 @@ int GlmTest::resampSmryCase(glm *model, gsl_matrix *bT, GrpMat *GrpXs, gsl_matri
                gsl_matrix_set_row(bO, j, &oj.vector);
            }
            if (tm->reprand!=TRUE) PutRNGstate();
-           gsl_matrix_set_zero(tXX);
-           gsl_blas_dsyrk (CblasLower,CblasTrans,1.0,GrpXs[0].matrix,0.0,tXX);
-           if ( calcDet(tXX) > eps ) isSingular=FALSE; 
+           gsl_matrix_set_identity(tXX);
+           gsl_blas_dsyrk(CblasLower,CblasTrans,1.0,GrpXs[0].matrix,0.0,tXX);
+           status=gsl_linalg_cholesky_decomp(tXX); 
+           if (status!=GSL_EDOM) break;
+          //  if (calcDet(tXX)>eps) break; 
        }
        for (k=2; k<nParam+2; k++) 
            subX2(GrpXs[0].matrix, k-2, GrpXs[k].matrix);
@@ -763,21 +764,22 @@ int GlmTest::resampSmryCase(glm *model, gsl_matrix *bT, GrpMat *GrpXs, gsl_matri
 //int GlmTest::resampAnovaCase(glm *model, gsl_matrix *Onull, gsl_matrix *bT, gsl_matrix *bX, gsl_matrix *bO, gsl_matrix *bOnull, unsigned int i)
 int GlmTest::resampAnovaCase(glm *model, gsl_matrix *bT, gsl_matrix *bX, gsl_matrix *bO, unsigned int i)
 {
-    unsigned int j, id, isSingular, nP;
+    gsl_set_error_handler_off();
+    int status, isValid=TRUE;
+
+    unsigned int j, id, nP;
     gsl_vector_view yj, xj, oj; 
     nP = model->Xref->size2;
-    gsl_matrix *txX = gsl_matrix_alloc(nP, nP);
-    gsl_matrix_set_zero(txX);
+    gsl_matrix *tXX = gsl_matrix_alloc(nP, nP);
     unsigned int nRows=tm->nRows;
 
     if (bootID == NULL) {
-       isSingular=TRUE;
-       while (isSingular==TRUE) {
+       while (isValid==TRUE) {
             if (tm->reprand!=TRUE) GetRNGstate();
             for (j=0; j<nRows; j++) {   
                 if (tm->reprand==TRUE)
-                   id = (unsigned int) gsl_rng_uniform_int(rnd, nRows);
-                else id = (unsigned int) nRows * Rf_runif(0, 1);
+                   id=(unsigned int)gsl_rng_uniform_int(rnd, nRows);
+                else id=(unsigned int) nRows*Rf_runif(0, 1);
                 // resample Y and X and offset
                 yj=gsl_matrix_row(model->Yref, id);
                 xj = gsl_matrix_row(model->Xref, id);
@@ -785,11 +787,12 @@ int GlmTest::resampAnovaCase(glm *model, gsl_matrix *bT, gsl_matrix *bX, gsl_mat
                 gsl_matrix_set_row (bT, j, &yj.vector);
                 gsl_matrix_set_row(bX, j, &xj.vector);
                 gsl_matrix_set_row(bO, j, &oj.vector);
-//                gsl_matrix_set_row(bOnull, j, &o0j.vector);
              }
              if (tm->reprand!=TRUE) PutRNGstate();
-             gsl_blas_dsyrk (CblasLower, CblasTrans, 1.0, bX, 0.0, txX);
-             if (calcDet(txX)>eps) isSingular=FALSE;
+             gsl_matrix_set_identity(tXX);
+             gsl_blas_dsyrk(CblasLower,CblasTrans,1.0,bX,0.0,tXX);
+             status=gsl_linalg_cholesky_decomp(tXX); 
+             if (status!=GSL_EDOM) break;
        } 
    }   		    	
    else {
@@ -807,7 +810,7 @@ int GlmTest::resampAnovaCase(glm *model, gsl_matrix *bT, gsl_matrix *bX, gsl_mat
        }
    }
 
-   gsl_matrix_free(txX);
+   gsl_matrix_free(tXX);
 
    return SUCCESS;
 } 
